@@ -2,7 +2,7 @@ package HTTP::Entity::Parser::JSON;
 
 use strict;
 use warnings;
-use JSON qw//;
+use JSON::MaybeXS qw/decode_json/;
 use Encode qw/encode_utf8/;
 
 sub new {
@@ -19,7 +19,7 @@ sub add {
 sub finalize {
     my $self = shift;
 
-    my $p = JSON::decode_json($self->[0]);
+    my $p = decode_json($self->[0]);
     my @params;
     if (ref $p eq 'HASH') {
         while (my ($k, $v) = each %$p) {
@@ -27,8 +27,10 @@ sub finalize {
                 for (@$v) {
                     push @params, encode_utf8($k), encode_utf8($_);
                 }
+            } elsif (ref $v) {
+                push @params, encode_utf8($k), $v;
             } else {
-                push @params, encode_utf8($k), encode_utf8($v); 
+                push @params, encode_utf8($k), encode_utf8($v);
             }
         }
     }
@@ -48,7 +50,7 @@ HTTP::Entity::Parser::JSON - parser for application/json
 =head1 SYNOPSIS
 
     use HTTP::Entity::Parser;
-    
+
     my $parser = HTTP::Entity::Parser->new;
     $parser->register('application/json','HTTP::Entity::Parser::JSON');
 
